@@ -18,15 +18,19 @@
 #include "z_interp.h"
 #include <vector>
 
+namespace contourpy {
+
 template <typename Derived>
 class BaseContourGenerator : public ContourGenerator
 {
 public:
-    ~BaseContourGenerator();
+    virtual ~BaseContourGenerator();
 
     static FillType default_fill_type();
     static LineType default_line_type();
 
+    py::tuple filled(double lower_level, double upper_level) override;
+
     py::tuple get_chunk_count() const;  // Return (y_chunk_count, x_chunk_count)
     py::tuple get_chunk_size() const;   // Return (y_chunk_size, x_chunk_size)
 
@@ -39,8 +43,10 @@ public:
 
     ZInterp get_z_interp() const;
 
-    py::sequence filled(double lower_level, double upper_level);
-    py::sequence lines(double level);
+    py::sequence lines(double level) override;
+
+    py::list multi_filled(const LevelArray levels) override;
+    py::list multi_lines(const LevelArray levels) override;
 
     static bool supports_fill_type(FillType fill_type);
     static bool supports_line_type(LineType line_type);
@@ -83,12 +89,12 @@ protected:
         bool is_upper, on_boundary;
     };
 
-    // Calculate and return z at middle of quad.
-    double calc_middle_z(index_t quad) const;
-
     // Calculate, set and return z-level at middle of quad.
     ZLevel calc_and_set_middle_z_level(index_t quad);
 
+    // Calculate and return z at middle of quad.
+    double calc_middle_z(index_t quad) const;
+
     void closed_line(const Location& start_location, OuterOrHole outer_or_hole, ChunkLocal& local);
 
     void closed_line_wrapper(
@@ -97,11 +103,6 @@ protected:
     // If point/line/hole counts not consistent, throw runtime error.
     void check_consistent_counts(const ChunkLocal& local) const;
 
-    // Write points and offsets/codes to output numpy arrays.
-    void export_filled(ChunkLocal& local, std::vector<py::list>& return_lists);
-
-    void export_lines(ChunkLocal& local, std::vector<py::list>& return_lists);
-
     index_t find_look_S(index_t look_N_quad) const;
 
     // Return true if finished (i.e. back to start quad, direction and upper).
@@ -136,6 +137,10 @@ protected:
     double get_point_y(index_t point) const;
     double get_point_z(index_t point) const;
 
+    bool has_direct_line_offsets() const;
+    bool has_direct_outer_offsets() const;
+    bool has_direct_points() const;
+
     void init_cache_grid(const MaskArray& mask);
 
     // Either for a single chunk, or the whole domain (all chunks) if local == nullptr.
@@ -148,8 +153,6 @@ protected:
     void interp(
         index_t point0, double x1, double y1, double z1, bool is_upper, double*& points) const;
 
-    bool is_filled() const;
-
     bool is_point_in_chunk(index_t point, const ChunkLocal& local) const;
 
     bool is_quad_in_bounds(
@@ -165,6 +168,10 @@ protected:
 
     void move_to_next_boundary_edge(index_t& quad, index_t& forward, index_t& left) const;
 
+    // Common initialisation for filled/multi_filled and lines/multi_lines calls.
+    void pre_filled();
+    void pre_lines();
+
     void set_look_flags(index_t hole_start_quad);
 
     void write_cache_quad(index_t quad) const;
@@ -201,7 +208,10 @@ private:
     bool _direct_line_offsets;        // Whether line offsets array is written direct to Python.
     bool _direct_outer_offsets;       // Whether outer offsets array is written direct to Python.
     bool _outer_offsets_into_points;  // Otherwise into line offsets.  Only used if _identify_holes.
+    bool _nan_separated;              // Whether adjacent lines' points are separated by nans.
     unsigned int _return_list_count;
 };
 
+} // namespace contourpy
+
 #endif // CONTOURPY_BASE_H
