@@ -4,6 +4,8 @@
 #include "output_array.h"
 #include <iosfwd>
 
+namespace contourpy {
+
 struct ChunkLocal
 {
     ChunkLocal();
@@ -19,7 +21,7 @@ struct ChunkLocal
     int pass;
 
     // Data for whole pass.
-    count_t total_point_count;
+    count_t total_point_count;           // Includes nan separators if used.
     count_t line_count;                  // Count of all lines
     count_t hole_count;                  // Count of holes only.
 
@@ -33,4 +35,6 @@ struct ChunkLocal
     std::vector<index_t> look_up_quads;  // To find holes of current outer.
 };
 
+} // namespace contourpy
+
 #endif // CONTOURPY_CHUNK_LOCAL_H
