@@ -168,6 +168,8 @@
 
 /* ------------------------------------------------------------------------ */
 
+namespace contourpy {
+
 void print_Csite(Csite *Csite)
 {
     Cdata *data = Csite->data;
@@ -1451,7 +1453,6 @@ cntr_trace(Csite *site, double levels[], int nlevels)
     long n;
     long nparts = 0;
     long ntotal = 0;
-    long nparts2 = 0;
     long ntotal2 = 0;
 
     site->zlevel[0] = levels[0];
@@ -1507,7 +1508,6 @@ cntr_trace(Csite *site, double levels[], int nlevels)
             site->ycp += n;
             site->kcp += n;
             ntotal2 += n;
-            nparts2++;
         }
         else
         {
@@ -1522,3 +1522,5 @@ cntr_trace(Csite *site, double levels[], int nlevels)
     return build_cntr_list_v2(
         nseg0.data(), xp0.data(), yp0.data(), kp0.data(), nparts, ntotal, nlevels);
 }
+
+} // namespace contourpy
