@@ -399,7 +399,8 @@ void Mpl2014ContourGenerator::append_contour_to_vertices_and_codes(
             const ContourLine::Children& children = line.get_children();
             py::ssize_t npoints = static_cast<py::ssize_t>(line.size() + 1);
             for (children_it = children.begin(); children_it != children.end(); ++children_it)
-                 npoints += static_cast<py::ssize_t>((*children_it)->size() + 1);
+                // cppcheck-suppress useStlAlgorithm
+                npoints += static_cast<py::ssize_t>((*children_it)->size() + 1);
 
             py::ssize_t vertices_dims[2] = {npoints, 2};
             PointArray vertices(vertices_dims);
@@ -482,16 +483,13 @@ void Mpl2014ContourGenerator::edge_interp(
            level, contour_line);
 }
 
-py::tuple Mpl2014ContourGenerator::filled(
-    const double& lower_level, const double& upper_level)
+py::tuple Mpl2014ContourGenerator::filled(double lower_level, double upper_level)
 {
-    if (lower_level >= upper_level)
-        throw std::invalid_argument("upper_level must be larger than lower_level");
+    check_levels(lower_level, upper_level);
 
     init_cache_levels(lower_level, upper_level);
 
     Contour contour;
-
     py::list vertices, codes;
 
     index_t ichunk, jchunk, istart, iend, jstart, jend;
@@ -642,8 +640,7 @@ unsigned int Mpl2014ContourGenerator::follow_boundary(
         // Add point to contour.
         get_point_xy(end_point, contour_line);
 
-        if (first_edge)
-            first_edge = false;
+        first_edge = false;
     }
 
     return level_index;
@@ -1218,7 +1215,7 @@ bool Mpl2014ContourGenerator::is_edge_a_boundary(
     }
 }
 
-py::tuple Mpl2014ContourGenerator::lines(const double& level)
+py::sequence Mpl2014ContourGenerator::lines(double level)
 {
     init_cache_levels(level, level);
 
