@@ -1,13 +1,26 @@
+from __future__ import annotations
+
 import os
 from shutil import copyfile
+from typing import TYPE_CHECKING
 
 import numpy as np
 
+if TYPE_CHECKING:
+    import io
 
-def compare_images(test_buffer, baseline_filename, test_filename_suffix=None, max_threshold=None,
-                   mean_threshold=None):
+
+def compare_images(
+    test_buffer: io.BytesIO,
+    baseline_filename: str,
+    test_filename_suffix: str | None = None,
+    max_threshold: int | None = None,
+    mean_threshold: float | None = None,
+) -> None:
     from PIL import Image
 
+    from .conftest import image_diffs_log
+
     if max_threshold is None:
         max_threshold = 100
     if mean_threshold is None:
@@ -40,6 +53,9 @@ def compare_images(test_buffer, baseline_filename, test_filename_suffix=None, ma
         max_diff = diff.max()
         mean_diff = diff.mean()
 
+        log = f"{max_diff},{max_threshold},{mean_diff:g},{mean_threshold},{test_filename}"
+        image_diffs_log.append(log)
+
         assert max_diff < max_threshold and mean_diff < mean_threshold
     except AssertionError:
         # Write test image.
